CacheEncryptionConfig class final
Configures how SecureCache manages its AES-256-GCM key and handles
plaintext bytes after encryption.
Constructors
- CacheEncryptionConfig({String keyAlias = 'super_cache_aes256_key', bool wipeOnEviction = true})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyAlias → String
-
The key under which the AES-256 key is stored in the
KeyStore.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wipeOnEviction → bool
-
When
true(default), the plaintextUint8Listproduced by the codec is zero-filled withUint8List.fillRangeimmediately after the value is encrypted duringSecureCache.put.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited